*-------------------------------------------------------------------------------------------------------------------------------------

* CIS - Community Innovation Survey 3 - Data without Boundaries (Work Package 5)
*
* This routine converts CIS 3 Hungary data formatted in CSV into DTA.
* Checked for the July 2013 release of the CIS, as provided by Eurostat.

* Version 1 of the routine, March 2015
* STATA 12

* University of Ljubljana, Social Science Data Archives, partners of Data without Boundaries project
* Sebastian Kocar
* http://www.adp.fdv.uni-lj.si/
* Contact: arhiv.podatkov@fdv.uni-lj.si
*
* This STATA code is protected under the creative commons license.
*
*-------------------------------------------------------------------------------------------------------------------------------------
*
* --- EXCEL DATA EXPORT---
*
* To use this STATA code, CIS 3 Hungary Excel 1997-2003 data file has to be exported/saved as 
* CSV data file in Microsoft Office Excel (with a comma as a separator and a dot as a decimal 
* separator, with no exceptions!). 
* PLEASE NOTE that decimal separators in Excel should be set to commas (,) before saving the dataset as
* a CSV dataset. After that the following two actions should be done in that specific order using
* a text editor: (1) replacing  commas (,) with dots (.), (2) replacing semicolons (;) with commas (,).
* The database in .csv format should then be imported into STATA and later processed using  the
* commands below.
*
*-------------------------------------------------------------------------------------------------------------------------------------


/* Initialization commands */
clear
capture log close
set more off
version 12.0
set linesize 250
set varabbrev off
set memory 1G // not necessary in Stata 12


* ----------------------------------------------------------------------------

* --- CONFIGURATION SECTION - START ---

* The following command should contain the complete path and
* name of the Stata log file.
* Change LOG_FILENAME to your filename, below:
local log_file "LOG_FILENAME"


* The following command should contain the complete path and
* name of the CSV file, usual file extension ".csv"
* Change CSV_DATA_PATH to your filename, below:
local csvpath "CSV_DATA_PATH"


* The following command should contain the complete path and
* name of the STATA file, usual file extension ".dta"
* Change STATA_DATA_PATH to your filename, below:
local statapath "STATA_DATA_PATH"


* --- CONFIGURATION SECTION - END ---

* ----------------------------------------------------------------------------



* There should be nothing to change below this line
* ----------------------------------------------------------------------------



log using "`log_file'", replace text

insheet using "`csvpath'", comma names case

* Note that some variables in the csv raw data file might be in lowercase
* To ensure that the dataset contains only variable names in uppercase

foreach var of varlist _all {
    local newname = upper("`var'")
    cap rename `var' `newname'
}


* Recode string variables which have labels, to numeric variables

generate TEMPVAR = .
replace TEMPVAR = 1 if NACE2_N == "10"
replace TEMPVAR = 2 if NACE2_N == "10_11"
replace TEMPVAR = 3 if NACE2_N == "10_11_12"
replace TEMPVAR = 4 if NACE2_N == "10_11_13"
replace TEMPVAR = 5 if NACE2_N == "10_11_14"
replace TEMPVAR = 6 if NACE2_N == "10_14"
replace TEMPVAR = 7 if NACE2_N == "11_12_14"
replace TEMPVAR = 8 if NACE2_N == "11_14"
replace TEMPVAR = 9 if NACE2_N == "12_13"
replace TEMPVAR = 10 if NACE2_N == "13_14"
replace TEMPVAR = 11 if NACE2_N == "14"
replace TEMPVAR = 12 if NACE2_N == "14_15"
replace TEMPVAR = 13 if NACE2_N == "15"
replace TEMPVAR = 14 if NACE2_N == "15_15"
replace TEMPVAR = 15 if NACE2_N == "15_16"
replace TEMPVAR = 16 if NACE2_N == "16"
replace TEMPVAR = 17 if NACE2_N == "17"
replace TEMPVAR = 18 if NACE2_N == "17_18"
replace TEMPVAR = 19 if NACE2_N == "18"
replace TEMPVAR = 20 if NACE2_N == "18_19"
replace TEMPVAR = 21 if NACE2_N == "19"
replace TEMPVAR = 22 if NACE2_N == "19_20"
replace TEMPVAR = 23 if NACE2_N == "20"
replace TEMPVAR = 24 if NACE2_N == "20_21"
replace TEMPVAR = 25 if NACE2_N == "20_21_22"
replace TEMPVAR = 26 if NACE2_N == "21"
replace TEMPVAR = 27 if NACE2_N == "22"
replace TEMPVAR = 28 if NACE2_N == "22_23"
replace TEMPVAR = 29 if NACE2_N == "23"
replace TEMPVAR = 30 if NACE2_N == "23_24"
replace TEMPVAR = 31 if NACE2_N == "24"
replace TEMPVAR = 32 if NACE2_N == "24_25"
replace TEMPVAR = 33 if NACE2_N == "25"
replace TEMPVAR = 34 if NACE2_N == "26"
replace TEMPVAR = 35 if NACE2_N == "26_27"
replace TEMPVAR = 36 if NACE2_N == "27"
replace TEMPVAR = 37 if NACE2_N == "27_28"
replace TEMPVAR = 38 if NACE2_N == "28"
replace TEMPVAR = 39 if NACE2_N == "29"
replace TEMPVAR = 40 if NACE2_N == "30"
replace TEMPVAR = 41 if NACE2_N == "30_31"
replace TEMPVAR = 42 if NACE2_N == "31"
replace TEMPVAR = 43 if NACE2_N == "31_33"
replace TEMPVAR = 44 if NACE2_N == "32"
replace TEMPVAR = 45 if NACE2_N == "33"
replace TEMPVAR = 46 if NACE2_N == "33_34"
replace TEMPVAR = 47 if NACE2_N == "34"
replace TEMPVAR = 48 if NACE2_N == "34_35"
replace TEMPVAR = 49 if NACE2_N == "35"
replace TEMPVAR = 50 if NACE2_N == "36"
replace TEMPVAR = 51 if NACE2_N == "36_37"
replace TEMPVAR = 52 if NACE2_N == "36_40_41"
replace TEMPVAR = 53 if NACE2_N == "37"
replace TEMPVAR = 54 if NACE2_N == "40"
replace TEMPVAR = 55 if NACE2_N == "40_41"
replace TEMPVAR = 56 if NACE2_N == "41"
replace TEMPVAR = 57 if NACE2_N == "51"
replace TEMPVAR = 58 if NACE2_N == "60"
replace TEMPVAR = 59 if NACE2_N == "60_61"
replace TEMPVAR = 60 if NACE2_N == "60_61_62"
replace TEMPVAR = 61 if NACE2_N == "61"
replace TEMPVAR = 62 if NACE2_N == "61_62"
replace TEMPVAR = 63 if NACE2_N == "62"
replace TEMPVAR = 64 if NACE2_N == "62_63"
replace TEMPVAR = 65 if NACE2_N == "63"
replace TEMPVAR = 66 if NACE2_N == "63_64"
replace TEMPVAR = 67 if NACE2_N == "64"
replace TEMPVAR = 68 if NACE2_N == "64_65_66_67"
replace TEMPVAR = 69 if NACE2_N == "65"
replace TEMPVAR = 70 if NACE2_N == "65_66_67"
replace TEMPVAR = 71 if NACE2_N == "66"
replace TEMPVAR = 72 if NACE2_N == "66_67"
replace TEMPVAR = 73 if NACE2_N == "67"
replace TEMPVAR = 74 if NACE2_N == "72"
replace TEMPVAR = 75 if NACE2_N == "72_73"
replace TEMPVAR = 76 if NACE2_N == "73"
replace TEMPVAR = 77 if NACE2_N == "74"
drop NACE2_N
rename TEMPVAR NACE2_N

generate TEMPVAR = .
replace TEMPVAR = 1 if SIZE98_N == "       0"
replace TEMPVAR = 2 if SIZE98_N == "       1"
replace TEMPVAR = 3 if SIZE98_N == "       2"
replace TEMPVAR = 4 if SIZE98_N == "       3"
replace TEMPVAR = 5 if SIZE98_N == "0.1_2"
replace TEMPVAR = 6 if SIZE98_N == "0_1"
replace TEMPVAR = 7 if SIZE98_N == "0_1_2"
replace TEMPVAR = 8 if SIZE98_N == "0_1_2.3"
replace TEMPVAR = 9 if SIZE98_N == "0_1_2_3"
replace TEMPVAR = 10 if SIZE98_N == "0_1_3"
replace TEMPVAR = 11 if SIZE98_N == "0_2"
replace TEMPVAR = 12 if SIZE98_N == "0_2_3"
replace TEMPVAR = 13 if SIZE98_N == "1_2"
replace TEMPVAR = 14 if SIZE98_N == "1_2_3"
replace TEMPVAR = 15 if SIZE98_N == "1_3"
replace TEMPVAR = 16 if SIZE98_N == "2_3"
drop SIZE98_N
rename TEMPVAR SIZE98_N

generate TEMPVAR = .
replace TEMPVAR = 1 if SIZE00_N == "       1"
replace TEMPVAR = 2 if SIZE00_N == "       2"
replace TEMPVAR = 3 if SIZE00_N == "       3"
replace TEMPVAR = 4 if SIZE00_N == "1_2"
replace TEMPVAR = 5 if SIZE00_N == "1_2_3"
replace TEMPVAR = 6 if SIZE00_N == "1_3"
replace TEMPVAR = 7 if SIZE00_N == "2_3"
drop SIZE00_N
rename TEMPVAR SIZE00_N



* Force variables as numeric

replace TURN98 = "" if TURN98 == ""
replace TURN98 = "" if TURN98 == "N.A."
destring TURN98, replace

replace EXP = "" if EXP == ""
replace EXP = "" if EXP == "N.A."
destring EXP, replace

replace INVTA = "" if INVTA == ""
replace INVTA = "" if INVTA == "N.A."
destring INVTA, replace

replace RRDINX = "" if RRDINX == ""
replace RRDINX = "" if RRDINX == "N.A."
destring RRDINX, replace

replace RRDEXX = "" if RRDEXX == ""
replace RRDEXX = "" if RRDEXX == "N.A."
destring RRDEXX, replace

replace RMACX = "" if RMACX == ""
replace RMACX = "" if RMACX == "N.A."
destring RMACX, replace

replace ROEKX = "" if ROEKX == ""
replace ROEKX = "" if ROEKX == "N.A."
destring ROEKX, replace

replace ROTHX = "" if ROTHX == ""
replace ROTHX = "" if ROTHX == "N.A."
destring ROTHX, replace

replace RTOT = "" if RTOT == ""
replace RTOT = "" if RTOT == "N.A."
destring RTOT, replace

replace RDPER = "" if RDPER == ""
replace RDPER = "" if RDPER == "N.A."
destring RDPER, replace

replace EMPHI = "" if EMPHI == ""
replace EMPHI = "" if EMPHI == "N.A."
destring EMPHI, replace



* Definition of variable labels
* Please note that the reference period is not 1998-2000 for all countries. Please check CIS 3 
* country level metadata.


label variable NUTS_2DIG "Country"
label variable NACE2_N   "Main activity"
label variable GP        "Enterprise part of a group"
label variable C_HO      "Country of head office"
label variable EST       "Establishment of enterprise between 1998 and 2000"
label variable TURNINC   "Turnover increased 1998-2000"
label variable TURNDEC   "Turnover decreased 1998-2000"
label variable SIGMAR    "Most significant markets in 1998-2000"
label variable TURN98    "Total turnover in 1998"
label variable TURN      "Total turnover in 2000"
label variable EXP98     "Export in 1998"
label variable EXP       "Export in 2000"
label variable INVTA     "Gross investment in tangible goods in 2000"
label variable SIZE98_N  "Total number of employees in 1998"
label variable SIZE00_N  "Total number of employees in 2000"
label variable EMPHI     "Total number of employees in 2000, of which: with higher education"
label variable INPDT     "Introduced onto the market a new or significantly improved goods or services"
label variable INPDTW    "Who mainly developed these products"
label variable TURNIN    "% of turnover in  unchanged or marginally modified products during 1998-2000 that were new to the firm"
label variable TURNUNG   "% of turnover in  unchanged or marginally modified products during 1998-2000"
label variable INMAR     "Introducing new or significantly improved products, new for the enterprise's market"
label variable TURNMAR   "% of turnover in new or improved products introduced during 1998-2000 that were new to the market"
label variable INPCS     "Introduced onto the market a new or significantly improved method of production"
label variable INPCSW    "Who mainly developed these processes"
label variable INON      "Enterprise with ongoing or abandoned innovation activities"
label variable INAB      "Abandoned or suspended before completion"
label variable RRDIN     "Engagement in intramural R&D"
label variable RRDINX    "Expenditure in intramural R&D"
label variable RRDEX     "Engagement in extramural R&D"
label variable RRDEXX    "Purchase of extramural R&D"
label variable RMAC      "Engagement in acquisition of machinery"
label variable RMACX     "Expenditure in acquisition of machinery"
label variable ROEK      "Engagement in acquisition of external knowledge"
label variable ROEKX     "Expenditure in acquisition of external knowledge"
label variable RTR       "Engagement in training for innovative activities"
label variable RMAR      "Engagement in market introduction of innovation"
label variable RPRE      "Engagement in other preparation"
label variable ROTHX     "Other expenditure (in training, market innovation, design)"
label variable RTOT      "Total of these four innovation expenditure categories"
label variable RDPER     "People involved in R&D in 2000"
label variable RDENG     "Type of engagement in R&D"
label variable ERANGE    "Increased range of goods or services"
label variable EMAR      "Increased market or market share"
label variable EQUA      "Improved quality in goods or services"
label variable EFLEX     "Improved production flexibility"
label variable ECAP      "Improved production capacity"
label variable ELBR      "Reduced labour costs per produced unit"
label variable EMAT      "Reduced materials and energy per produced unit"
label variable EENV      "Reduced environmental impact or health and safety aspects"
label variable ESTD      "Met regulations or standards"
label variable FUNLOC    "Public funding from local or regional authorities"
label variable FUNGMT    "Public funding from central government"
label variable FUNEU     "Public funding from the EU"
label variable FUNRTD    "Funding from EU's 4th, 5th, 6th or 7th Framework Programme for RTD"
label variable CO        "Cooperation arrangements on innovation activities"
label variable CO11      "Other enterprises within enterprise group : National"
label variable CO12      "Other enterprises within enterprise group : EU/EFTA"
label variable CO13      "Other enterprises within enterprise group : EU-CC"
label variable CO14      "Other enterprises within enterprise group : US"
label variable CO15      "Other enterprises within enterprise group : Japan"
label variable CO16      "Other enterprises within enterprise group : Other countries"
label variable CO21      "Suppliers of equipment, etc. : National"
label variable CO22      "Suppliers of equipment, etc. : EU/EFTA"
label variable CO23      "Suppliers of equipment, etc. : EU-CC"
label variable CO24      "Suppliers of equipment, etc. : US"
label variable CO25      "Suppliers of equipment, etc. : Japan"
label variable CO26      "Suppliers of equipment, etc. :  Other countries"
label variable CO31      "Clients or customers : National"
label variable CO32      "Clients or customers : EU/EFTA"
label variable CO33      "Clients or customers : EU-CC"
label variable CO34      "Clients or customers : US"
label variable CO35      "Clients or customers : Japan"
label variable CO36      "Clients or customers : Other countries"
label variable CO41      "Competitors or other firms  : National"
label variable CO42      "Competitors or other firms  : EU/EFTA"
label variable CO43      "Competitors or other firms  : EU-CC"
label variable CO44      "Competitors or other firms  : US"
label variable CO45      "Competitors or other firms  : Japan"
label variable CO46      "Competitors or other firms  : Other countries"
label variable CO51      "Consultants: National"
label variable CO52      "Consultants: EU/EFTA"
label variable CO53      "Consultants: EU-CC"
label variable CO54      "Consultants: US"
label variable CO55      "Consultants: Japan"
label variable CO56      "Consultants: Other countries"
label variable CO61      "Commercial laboratories /R&D enterprises : National"
label variable CO62      "Commercial laboratories /R&D enterprises : EU/EFTA"
label variable CO63      "Commercial laboratories /R&D enterprises : EU-CC"
label variable CO64      "Commercial laboratories /R&D enterprises : US"
label variable CO65      "Commercial laboratories /R&D enterprises : Japan"
label variable CO66      "Commercial laboratories /R&D enterprises : Other countries"
label variable CO71      "Universities or other  : National"
label variable CO72      "Universities or other  : EU/EFTA"
label variable CO73      "Universities or other  : EU-CC"
label variable CO74      "Universities or other  : US"
label variable CO75      "Universities or other  : Japan"
label variable CO76      "Universities or other  : Other countries"
label variable CO81      "Government or public research institutes: National"
label variable CO82      "Government or public research institutes:  EU/EFTA"
label variable CO83      "Government or public research institutes:  EU-CC"
label variable CO84      "Government or public research institutes: US"
label variable CO85      "Government or public research institutes: Japan"
label variable CO86      "Government or public research institutes: Other countries"
label variable SENT      "Sources from within the enterprise"
label variable SGRP      "Sources from other enterprises within the enterprise group"
label variable SSUP      "Sources from Suppliers of equipment, materials, etc."
label variable SCLI      "Sources from Clients or customers"
label variable SCOM      "Sources from Competitors and other enterprises of same industry"
label variable SUNI      "Sources from Universities or other higher education institutes"
label variable SGMT      "Sources from Government or public research institutes"
label variable SPRO      "Sources from Professional and industry associations"
label variable SEXB      "Sources from fairs, exhibitions"
label variable HDLAY     "Innovation activity seriously delayed"
label variable HSTAR     "Innovation activity prevented to be started"
label variable HBUR      "Innovation activity burdened/cumbered with other serious problems"
label variable HPRIOR    "No innovation activity due to prior innovations"
label variable HMAR      "No innovation activity due to no demand for innovations"
label variable HIMP      "No innovation activity due to factors impeding innovation?"
label variable HECO      "Hampering factor : Excessive perceived economic risks"
label variable HCOS      "Hampering factor : Innovation costs too high"
label variable HFIN      "Hampering factor : Lack of appropriate sources of finance"
label variable HORG      "Hampering factor : Organisational rigidities within the enterprise"
label variable HPER      "Hampering factor : Lack of qualified personnel"
label variable HTEC      "Hampering factor : Lack of information on technology"
label variable HINF      "Hampering factor : Lack of information on markets"
label variable HFLEX     "Hampering factor : Insufficient flexibility of regulations or standards"
label variable HCUS      "Hampering factor : Lack of customer responsiveness to new goods or services"
label variable PAAP      "Applied for a patent"
label variable PAVAL     "Having valid patents"
label variable PROREG    "Registration of design patterns"
label variable PROTM     "Register a trademark"
label variable PROCP     "Claimed copyright"
label variable PROSEC    "Protecting inventions or innovations by Secrecy"
label variable PRODES    "Protecting inventions or innovations by Complexity of design"
label variable PROTIM    "Protecting inventions or innovations by Lead-time advantage on competitors"
label variable ACTSTR    "Strategical changes"
label variable ACTMAN    "Management changes"
label variable ACTORG    "Organizational changes"
label variable ACTMAR    "Marketing changes"
label variable ACTAES    "Aesthetic changes (or other subjective changes)"
label variable W2USE     "Weighting factor"


* Definition of category labels

label define LABELS_GROUP_1 0 "No answer" 1 "Home Country" 2 "EU, EFTA, CC" 3 "rest of the world"
label define LABELS_GROUP_2 0 "No" 1 "Yes"
label define LABELS_GROUP_3 1 "Local/ regional (within a distance of around 50 km) within your country" 2 "Local/ regional (within a distance of around 50 km) within your neighbouring countries" 3 "National (with a distance of more than 50 km)" 4 "International (with a distance of more than 50 km)"
label define LABELS_GROUP_4 1 "Mainly your enterprise or enterprise group" 2 "Your enterprise in co-operation with other enterprises or institutions" 3 "Mainly other enterprises or institutions"
label define LABELS_GROUP_5 1 "Continuously" 2 "Occasionally"
label define LABELS_GROUP_6 0 "Not relevant" 1 "Low" 2 "Med" 3 "High"
label define LABELS_GROUP_7 0 "Not selected" 1 "Selected"
label define LABELS_GROUP_8 0 "Not used" 1 "Low" 2 "Med" 3 "High"
label define LABELS_GROUP_9 1 "Mining of coal and lignite; extraction of peat" 2 "Mining of coal, lignite; extraction of peat, crude petroleum, gas; service activities incidental to oil, gas extraction" 3 "Mining and quarrying of energy producing materials" 4 "Mining of coal, lignite, uranium, metal ores; extraction of peat, crude petroleum and natural gas" 5 "Mining of coal, lignite, uranium, other mining; extraction of peat, crude petroleum and natural gas" 6 "Mining of coal and lignite; extraction of peat; other mining and quarrying" 7 "Extraction of crude petroleum and natural gas; Mining of uranium and thorium ores; Other mining and quarrying" 8 "Extraction of crude petroleum and natural gas; Other mining and quarrying" 9 "Mining of uranium and thorium ores; Mining of metal ores" 10 "Mining and quarrying, except of energy producing materials" 11 "Other mining and quarrying" 12 "Other mining and quarrying; Manufacture of food products and beverages" 13 "Manufacture of food products and beverages" 14 "Manufacture of food products, beverages and tobacco (Portuguese coding)" 15 "Manufacture of food products, beverages and tobacco" 16 "Manufacture of tobacco products" 17 "Manufacture of textiles" 18 "Manufacture of textiles and textile products" 19 "Manufacture of wearing apparel; dressing and dyeing of fur" 20 "Manufacture of wearing apparel, luggage/handbags/saddlery/harness/footwear; dressing, dyeing of fur; tanning of leather" 21 "Manufacture of leather and leather products" 22 "Manufacture of leather and leather products; Manufacture of wood and wood products" 23 "Manufacture of wood and wood products" 24 "Manufacture of wood and wood products; Manufacture of pulp, paper and paper products" 25 "Manufacture of wood and wood products; Manufacture of pulp, paper and paper products; publishing and printing" 26 "Manufacture of pulp, paper and paper products" 27 "Publishing, printing and reproduction of recorded media" 28 "Publishing, printing , reproduction of recorded media;  Manufacture of coke, refined petroleum products and nuclear fuel" 29 "Manufacture of coke, refined petroleum products and nuclear fuel" 30 "Manufacture of coke, refined petroleum products and nuclear fuel; Manufacture of chemicals and chemical products" 31 "Manufacture of chemicals and chemical products" 32 "Manufacture of chemicals and chemical products; Manufacture of rubber and plastic products" 33 "Manufacture of rubber and plastic products" 34 "Manufacture of other non-metallic mineral products" 35 "Manufacture of other non-metallic mineral products;  Manufacture of basic metals" 36 "Manufacture of basic metals" 37 "Manufacture of basic metals and fabricated metal products" 38 "Manufacture of fabricated metal products, except machinery and equipment" 39 "Manufacture of machinery and equipment n.e.c." 40 "Manufacture of office machinery and computers" 41 "Manufacture of office machinery and computers; manufacture of electrical machinery and apparatus n.e.c." 42 "Manufacture of electrical machinery and apparatus n.e.c." 43 "Manufacture of electrical machinery and apparatus n.e.c.; medical, precision and optical instruments, watches and clocks" 44 "Manufacture of radio, television and communication equipment and apparatus" 45 "Manufacture of medical, precision and optical instruments, watches and clocks" 46 "Manufacture of medical, precision and optical instruments, watches, clocks; of motor vehicles, trailers, semi-trailers" 47 "Manufacture of motor vehicles, trailers and semi-trailers" 48 "Manufacture of transport equipment" 49 "Manufacture of other transport equipment" 50 "Manufacture of furniture; manufacturing n.e.c." 51 "Manufacture of furniture; manufacturing n.e.c.; Recycling" 52 "Manufacture of furniture; manufacturing n.e.c.;  Electricity, gas and water supply" 53 "Recycling" 54 "Electricity, gas, steam and hot water supply" 55 "Electricity, gas, steam and hot water supply; collection, purification and distribution of water" 56 "Collection, purification and distribution of water" 57 "Wholesale trade and commission trade, except of motor vehicles and motorcycles" 58 "Land transport; transport via pipelines" 59 "Land transport; transport via pipelines; Water transport" 60 "Land transport; transport via pipelines; Water transport; Air transport" 61 "Water transport" 62 "Water transport; Air transport" 63 "Air transport" 64 "Air transport; Supporting and auxiliary transport activities; activities of travel agencies" 65 "Supporting and auxiliary transport activities; activities of travel agencies" 66 "Supporting and auxiliary transport activities; activities of travel agencies; Post and telecommunications" 67 "Post and telecommunications" 68 "Post and telecommunications; Financial intermediation" 69 "Financial intermediation, except insurance and pension funding" 70 "Financial intermediation" 71 "Insurance and pension funding, except compulsory social security" 72 "Insurance and pension funding, except compulsory social security;  Activities auxiliary to financial intermediation" 73 "Activities auxiliary to financial intermediation" 74 "Computer and related activities" 75 "Computer and related activities; Research and development" 76 "Research and development" 77 "Other business activities"
label define LABELS_GROUP_10 1 "10-19" 2 "20-49" 3 "50-249" 4 "250+" 5 "10-249" 6 "10-49" 7 "10-249" 8 "10+" 9 "10+" 10 "10-49 & 250+" 11 "10-19 & 50-249" 12 "10-19 & 50+" 13 "20-249" 14 "20+" 15 "20-49 & 250+" 16 "50+"
label define LABELS_GROUP_11 1 "10-49" 2 "50-249" 3 "250+" 4 "10-249" 5 "10+" 6 "10-49 & 250+" 7 "50+"


* Attachment of category labels to variables

label values C_HO      LABELS_GROUP_1
label values GP        LABELS_GROUP_2
label values EST       LABELS_GROUP_2
label values TURNINC   LABELS_GROUP_2
label values TURNDEC   LABELS_GROUP_2
label values INPDT     LABELS_GROUP_2
label values INMAR     LABELS_GROUP_2
label values INPCS     LABELS_GROUP_2
label values INON      LABELS_GROUP_2
label values INAB      LABELS_GROUP_2
label values RRDIN     LABELS_GROUP_2
label values RRDEX     LABELS_GROUP_2
label values RMAC      LABELS_GROUP_2
label values ROEK      LABELS_GROUP_2
label values RTR       LABELS_GROUP_2
label values RMAR      LABELS_GROUP_2
label values RPRE      LABELS_GROUP_2
label values FUNLOC    LABELS_GROUP_2
label values FUNGMT    LABELS_GROUP_2
label values FUNEU     LABELS_GROUP_2
label values FUNRTD    LABELS_GROUP_2
label values CO        LABELS_GROUP_2
label values HDLAY     LABELS_GROUP_2
label values HSTAR     LABELS_GROUP_2
label values HBUR      LABELS_GROUP_2
label values HPRIOR    LABELS_GROUP_2
label values HMAR      LABELS_GROUP_2
label values HIMP      LABELS_GROUP_2
label values PAAP      LABELS_GROUP_2
label values PAVAL     LABELS_GROUP_2
label values PROREG    LABELS_GROUP_2
label values PROTM     LABELS_GROUP_2
label values PROCP     LABELS_GROUP_2
label values PROSEC    LABELS_GROUP_2
label values PRODES    LABELS_GROUP_2
label values PROTIM    LABELS_GROUP_2
label values ACTSTR    LABELS_GROUP_2
label values ACTMAN    LABELS_GROUP_2
label values ACTORG    LABELS_GROUP_2
label values ACTMAR    LABELS_GROUP_2
label values ACTAES    LABELS_GROUP_2
label values SIGMAR    LABELS_GROUP_3
label values INPDTW    LABELS_GROUP_4
label values INPCSW    LABELS_GROUP_4
label values RDENG     LABELS_GROUP_5
label values ERANGE    LABELS_GROUP_6
label values EMAR      LABELS_GROUP_6
label values EQUA      LABELS_GROUP_6
label values EFLEX     LABELS_GROUP_6
label values ECAP      LABELS_GROUP_6
label values ELBR      LABELS_GROUP_6
label values EMAT      LABELS_GROUP_6
label values EENV      LABELS_GROUP_6
label values ESTD      LABELS_GROUP_6
label values HECO      LABELS_GROUP_6
label values HCOS      LABELS_GROUP_6
label values HFIN      LABELS_GROUP_6
label values HORG      LABELS_GROUP_6
label values HPER      LABELS_GROUP_6
label values HTEC      LABELS_GROUP_6
label values HINF      LABELS_GROUP_6
label values HFLEX     LABELS_GROUP_6
label values HCUS      LABELS_GROUP_6
label values CO11      LABELS_GROUP_7
label values CO12      LABELS_GROUP_7
label values CO13      LABELS_GROUP_7
label values CO14      LABELS_GROUP_7
label values CO15      LABELS_GROUP_7
label values CO16      LABELS_GROUP_7
label values CO21      LABELS_GROUP_7
label values CO22      LABELS_GROUP_7
label values CO23      LABELS_GROUP_7
label values CO24      LABELS_GROUP_7
label values CO25      LABELS_GROUP_7
label values CO26      LABELS_GROUP_7
label values CO31      LABELS_GROUP_7
label values CO32      LABELS_GROUP_7
label values CO33      LABELS_GROUP_7
label values CO34      LABELS_GROUP_7
label values CO35      LABELS_GROUP_7
label values CO36      LABELS_GROUP_7
label values CO41      LABELS_GROUP_7
label values CO42      LABELS_GROUP_7
label values CO43      LABELS_GROUP_7
label values CO44      LABELS_GROUP_7
label values CO45      LABELS_GROUP_7
label values CO46      LABELS_GROUP_7
label values CO51      LABELS_GROUP_7
label values CO52      LABELS_GROUP_7
label values CO53      LABELS_GROUP_7
label values CO54      LABELS_GROUP_7
label values CO55      LABELS_GROUP_7
label values CO56      LABELS_GROUP_7
label values CO61      LABELS_GROUP_7
label values CO62      LABELS_GROUP_7
label values CO63      LABELS_GROUP_7
label values CO64      LABELS_GROUP_7
label values CO65      LABELS_GROUP_7
label values CO66      LABELS_GROUP_7
label values CO71      LABELS_GROUP_7
label values CO72      LABELS_GROUP_7
label values CO73      LABELS_GROUP_7
label values CO74      LABELS_GROUP_7
label values CO75      LABELS_GROUP_7
label values CO76      LABELS_GROUP_7
label values CO81      LABELS_GROUP_7
label values CO82      LABELS_GROUP_7
label values CO83      LABELS_GROUP_7
label values CO84      LABELS_GROUP_7
label values CO85      LABELS_GROUP_7
label values CO86      LABELS_GROUP_7
label values SENT      LABELS_GROUP_8
label values SGRP      LABELS_GROUP_8
label values SSUP      LABELS_GROUP_8
label values SCLI      LABELS_GROUP_8
label values SCOM      LABELS_GROUP_8
label values SUNI      LABELS_GROUP_8
label values SGMT      LABELS_GROUP_8
label values SPRO      LABELS_GROUP_8
label values SEXB      LABELS_GROUP_8
label values NACE2_N   LABELS_GROUP_9
label values SIZE98_N  LABELS_GROUP_10
label values SIZE00_N  LABELS_GROUP_11

compress
save "`statapath'", replace

log close
set more on
